@@ -11,6 +11,8 @@
 #include "calendarservice.h"
 #include "debug.h"
 #include "event.h"
+#include "fetchjob.h"
+#include "types.h"
 #include "utils.h"
 
 #include <QNetworkReply>
@@ -26,6 +28,7 @@ public:
     QString eventId;
     QString filter;
     QString syncToken;
+    QList<Event::EventType> eventTypes = { Event::EventType::Default, Event::EventType::FocusTime, Event::EventType::OutOfOffice };
     bool fetchDeleted = true;
     quint64 updatedTimestamp = 0;
     quint64 timeMin = 0;
@@ -157,6 +160,9 @@ void EventFetchJob::start()
         } else {
             query.addQueryItem(QStringLiteral("syncToken"), d->syncToken);
         }
+        for (auto eventType : d->eventTypes) {
+            query.addQueryItem(QStringLiteral("eventTypes"), CalendarService::eventTypeToString(eventType));
+        }
         url.setQuery(query);
     } else {
         url = CalendarService::fetchEventUrl(d->calendarId, d->eventId);
@@ -165,20 +171,21 @@ void EventFetchJob::start()
     enqueueRequest(request);
 }
 
-ObjectsList EventFetchJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData)
+bool EventFetchJob::handleError(int errorCode, const QByteArray &rawData)
 {
-    if (reply->error() == QNetworkReply::ContentGoneError || reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt() == Gone) {
+    if (errorCode == KGAPI2::Gone) {
         // Full sync required by server, redo request with no updatedMin and no syncToken
         d->updatedTimestamp = 0;
         d->syncToken.clear();
         start();
-        // Errors are not cleared on success
-        // Do it here or else the job will fail
-        setError(KGAPI2::NoError);
-        setErrorString(QString());
-        return ObjectsList();
+        return true;
     }
 
+    return FetchJob::handleError(errorCode, rawData);
+}
+
+ObjectsList EventFetchJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData)
+{
     FeedData feedData;
     feedData.requestUrl = reply->url();
     ObjectsList items;
