@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_DRIVEABOUTFETCHJOB_H
-#define KGAPI2_DRIVEABOUTFETCHJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "kgapidrive_export.h"
@@ -37,9 +36,7 @@ class KGAPIDRIVE_EXPORT AboutFetchJob : public KGAPI2::FetchJob
      *
      * This property can be modified only when the job is not running.
      */
-    Q_PROPERTY(bool includeSubscribed
-               READ includeSubscribed
-               WRITE setIncludeSubscribed)
+    Q_PROPERTY(bool includeSubscribed READ includeSubscribed WRITE setIncludeSubscribed)
 
     /**
      * @brief Maximum number of remaining change IDs to count.
@@ -48,9 +45,7 @@ class KGAPIDRIVE_EXPORT AboutFetchJob : public KGAPI2::FetchJob
      *
      * This property can be modified only when the job is not running.
      */
-    Q_PROPERTY(qlonglong maxChangeIdCount
-               READ maxChangeIdCount
-               WRITE setMaxChangeIdCount)
+    Q_PROPERTY(qlonglong maxChangeIdCount READ maxChangeIdCount WRITE setMaxChangeIdCount)
 
     /**
      * @brief Change ID to start counting from when calculating number of
@@ -60,11 +55,9 @@ class KGAPIDRIVE_EXPORT AboutFetchJob : public KGAPI2::FetchJob
      *
      * This property can be modified only when the job is not running.
      */
-    Q_PROPERTY(qlonglong startChangeId
-               READ startChangeId
-               WRITE setStartChangeId)
+    Q_PROPERTY(qlonglong startChangeId READ startChangeId WRITE setStartChangeId)
 
-  public:
+public:
     /**
      * @brief Constructs a new fetch job.
      *
@@ -86,7 +79,7 @@ class KGAPIDRIVE_EXPORT AboutFetchJob : public KGAPI2::FetchJob
     /**
      * @brief Returns whether to include shared and public files to change IDs count.
      */
-    bool includeSubscribed() const;
+    [[nodiscard]] bool includeSubscribed() const;
 
     /**
      * @brief Sets whether to include shared and public files to change IDs count.
@@ -98,7 +91,7 @@ class KGAPIDRIVE_EXPORT AboutFetchJob : public KGAPI2::FetchJob
     /**
      * @brief Returns maximum number of remaining change IDs to count.
      */
-    qlonglong maxChangeIdCount() const;
+    [[nodiscard]] qlonglong maxChangeIdCount() const;
 
     /**
      * @brief Sets maximum number of remaining change IDs to count.
@@ -111,7 +104,7 @@ class KGAPIDRIVE_EXPORT AboutFetchJob : public KGAPI2::FetchJob
      * @brief Returns change ID to start counting from when calculating number of
      *        remaining change IDs.
      */
-    qlonglong startChangeId() const;
+    [[nodiscard]] qlonglong startChangeId() const;
 
     /**
      * @brief Sets change ID to start counting from when calculating number of
@@ -126,9 +119,9 @@ class KGAPIDRIVE_EXPORT AboutFetchJob : public KGAPI2::FetchJob
      *
      * This method can only be called after the job has emitted finished()
      */
-    AboutPtr aboutData() const;
+    [[nodiscard]] AboutPtr aboutData() const;
 
-  protected:
+protected:
     /**
      * @brief KGAPI2::Job::start implementation
      */
@@ -140,18 +133,14 @@ class KGAPIDRIVE_EXPORT AboutFetchJob : public KGAPI2::FetchJob
      * @param reply
      * @param rawData
      */
-    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                                     const QByteArray &rawData) override;
+    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
 
-  private:
+private:
     class Private;
-    Private * const d;
+    Private *const d;
     friend class Private;
-
 };
 
 } // namespace Drive
 
 } // namespace KGAPI2
-
-#endif // DRIVEABOUTFETCHJOB_H
