@@ -76,7 +76,7 @@ public:
          * When this restriction is set to true, it will override the similarly
          * named field to true for any file inside this shared drive.
          */
-        Q_REQUIRED_RESULT bool copyRequiresWriterPermission() const;
+        [[nodiscard]] bool copyRequiresWriterPermission() const;
 
         /**
          * @brief Sets whether the options to copy, print, or download files
@@ -94,7 +94,7 @@ public:
          * shared drive belongs. This restriction may be overridden by other
          * sharing policies controlled outside of this shared drive.
          */
-        Q_REQUIRED_RESULT bool domainUsersOnly() const;
+        [[nodiscard]] bool domainUsersOnly() const;
 
         /**
          * @brief Sets whether access to this shared drive and items inside this
@@ -110,7 +110,7 @@ public:
          * @brief Returns whether access to items inside this shared drive is
          * restricted to its members.
          */
-        Q_REQUIRED_RESULT bool driveMembersOnly() const;
+        [[nodiscard]] bool driveMembersOnly() const;
 
         /**
          * @brief Sets whether access to items inside this shared drive is
